ViTEncoder

Struct ViTEncoder 

pub struct ViTEncoder {
    pub blocks: Vec<ViTBlock>,
    pub final_ln_weight: Vec<f32>,
    pub final_ln_bias: Vec<f32>,
}
Encoder stack: depth ViT blocks + a final layer norm.

Fields

blocks: Vec<ViTBlock>

The individual transformer blocks.

final_ln_weight: Vec<f32>

Final LayerNorm scale: [embed_dim].

final_ln_bias: Vec<f32>

Final LayerNorm bias: [embed_dim].

Implementations

Source

impl ViTEncoder

pub fn new(cfg: ViTEncoderConfig, rng: &mut LcgRng) -> VisionResult<Self>

Construct the encoder: depth blocks with independent weight initialisations from the shared rng.

The final layer-norm is initialised with weight=1, bias=0.

pub fn forward(&self, tokens: &[f32], n_tokens: usize) -> VisionResult<Vec<f32>>

Forward pass through all blocks then the final layer norm.

tokens: flat [n_tokens, embed_dim]. Returns [n_tokens, embed_dim].

pub fn embed_dim(&self) -> usize

Embedding dimension (read from the first block config).